import argparse
import pathlib

from JCompile import compiler

parser = argparse.ArgumentParser(description="compile json file")
parser.add_argument(
    "template_path", type=pathlib.Path, help="path of template json file"
)
parser.add_argument(
    "context_path", type=pathlib.Path, help="path of context json file"
)
parser.add_argument("save_path", type=pathlib.Path, help="path of save file")


def run():
    args = parser.parse_args()
    com_ = compiler.JsonCompiler.from_file(
        template_path=args.template_path, context_path=args.context_path
    )
    com_.to_file(save_path=args.save_path)


if __name__ == "__main__":
    run()



import json
from dataclasses import dataclass
from pathlib import Path


@dataclass
class JsonCompiler:
    template: str
    context: dict
    value = None
    _opening = '"{{'
    _closing = '}}"'

    def compile(self):
        t_ = str(self.template)
        for k_context, v_context in self.context.items():
            t_ = t_.replace(self._pattern(k_context), json.dumps(v_context))
        self.value = t_

    @classmethod
    def from_file(cls, template_path: Path, context_path: Path):
        with open(template_path, "r") as f_:
            template_ = f_.read()
        with open(context_path, "r") as f_:
            context_ = json.load(f_)
        return cls(template=template_, context=context_)

    def to_json(self):
        self.compile()
        return self.value

    def to_py(self):
        return json.loads(self.to_json())

    def to_file(self, save_path: Path):
        with open(save_path, "w") as f_:
            f_.write(self.to_json())

    def _pattern(self, key):
        return self._opening + key + self._closing
